@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #--------------------------------------------------------------------------------
-#www2sms.py v1.0.6
+#www2sms.py v1.1.0
 #Copyright Bjoern Olausson
 #--------------------------------------------------------------------------------
 #This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@ from www2sms_gui_dialog_progress import Ui_Form_Progress
 import www2sms_providers
 
 
-VERSION = "v1.0.6"
+VERSION = "v1.1.0"
 USER = pwd.getpwuid(os.getuid())[0]
 CONFIG_DIR = "/home/%s/MyDocs/www2sms" %(USER)
 
@@ -256,7 +256,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 		CharsLeft = self.max_c - SMS_CHARS
 		self.ui.label_SMSCharsLeft.setText(str(CharsLeft))
 		if SMS_CHARS > self.max_c and self.ui.pushButton_Send.isEnabled():
-		    	QMessageBox.information(self, 'www2sms', "Reached maximum allowd characters (%s)" %(self.max_c))
+		    	QMessageBox.information(self, 'www2sms', "Reached maximum allowed characters (%s)" %(self.max_c))
 		    	self.ui.pushButton_Send.setEnabled(False)
 		# Here we have to check if an Account exist, if not, we will not enable the send Button
 		if not self.ui.pushButton_Send.isEnabled() and SMS_CHARS <= self.max_c and self.AccSet.ui.comboBox_SetupAlias.currentText():
@@ -350,7 +350,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 		try:
 			s.connect((address, port))
 		except Exception, e:
-			QMessageBox.warning(self, 'www2sms', 'Please connect to the Internet bofore sending the SMS')
+			QMessageBox.warning(self, 'www2sms', 'Please connect to the Internet before sending the SMS')
 			return
 	    	# Read the provider to use
 		PROVIDER = unicode(self.AccSet.ui.comboBox_SetupProvider.currentText())
@@ -370,7 +370,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 			QMessageBox.warning(self, 'www2sms', message)
 			return
 		if FIXED_NUMBER != NUMBER:
-		    	reply = QMessageBox.question(self, 'www2sms', "Correcte number?\n%s --> %s" %(NUMBER, FIXED_NUMBER), QMessageBox.Yes, QMessageBox.No)
+		    	reply = QMessageBox.question(self, 'www2sms', "Correct number?\n%s --> %s" %(NUMBER, FIXED_NUMBER), QMessageBox.Yes, QMessageBox.No)
 		    	if reply == QMessageBox.Yes:
 			    	NUMBER = FIXED_NUMBER
 				self.ui.lineEdit_Number.setText(NUMBER)
