@@ -37,7 +37,7 @@ class provider():
 	def hasAdvancedFeatures(self):
 		return False
 	# Define the number of characters we can use per SMS.
-	# 160 is the default SMS length, some providers might strip it down to add som advert.
+	# 160 is the default SMS length, some providers might strip it down to add some advert.
 	# Second argument should be the maximum Length of a message.
 	def chars_per_sms(self):
 		return 160, 160
@@ -91,7 +91,7 @@ class provider_o2online_de(provider):
 		QtCore.QObject.connect(MainWindow.AdvSet.ui.comboBox_AdvancedScheduleStopMonth, QtCore.SIGNAL("activated(QString)"), on_StopDate_changed)
 		QtCore.QObject.connect(MainWindow.AdvSet.ui.comboBox_AdvancedScheduleStartYear, QtCore.SIGNAL("activated(QString)"), on_StartDate_changed)
 		QtCore.QObject.connect(MainWindow.AdvSet.ui.comboBox_AdvancedScheduleStopYear, QtCore.SIGNAL("activated(QString)"), on_StopDate_changed)
-		# TODO: Check wy the sheduling for o2online.de is not working.
+		# TODO: Check why the scheduling for o2online.de is not working.
 		# TODO: Meanwhile this is disabled.
 		MainWindow.AdvSet.ui.groupBox_AdvancedSchedule.setDisabled(True)
 
@@ -114,7 +114,7 @@ class provider_o2online_de(provider):
 		# RegExp to find the sucking CAPTCHA image
 		re_cap = re.compile('jcaptchaReg')
 		while re_cap.search(str(response)):
-			#Instaciate the CAPTCHA dialog
+			#Instantiate the CAPTCHA dialog
 			sc = ShowCAPTCHA()
 
 			## Download the CAPTCHA with urllib2
@@ -587,7 +587,7 @@ class provider_exetel_au(provider):
 		MainWindow.Stat.ui.progressBar.setMaximum(3)
 
 		# set up our browser
-		UpdatePbar(self, MainWindow, app, "1", "Initialising the browser")
+		UpdatePbar(self, MainWindow, app, "1", "Initializing the browser")
 		try:
 			br = mechanize.Browser()
 		except Exception, e:
@@ -717,18 +717,16 @@ class provider_MutluSMS_tu(provider):
 		#API URL
 		url = "http://www.mutlusms.com/api/gonder.do"
 		#Remove invalid chars from message
-		mesaj = re.sub(r'\^|\{|\}|\[|\]|\~|\\|\|', '', SMSTEXT)
+		MESSAGE = re.sub(r'\^|\{|\}|\[|\]|\~|\\|\|', '', SMSTEXT)
 		#Assemble REQUEST
-		urlSon = url + "?id=%s&sifre=%s&gonderen=%s&mesaj=%s&telefon=%s&flash=%s" %(LOGIN,PASSWORD,SENDER,mesaj,NUMBER,FLASH)
+		urlSon = url + "?id=%s&sifre=%s&gonderen=%s&mesaj=%s&telefon=%s&flash=%s" %(LOGIN,PASSWORD,SENDER,urllib.quote_plus(MESSAGE),NUMBER,FLASH)
 		UpdatePbar(self, MainWindow, app, "1", "Sending SMS")
-		print "VARS:", SENDER, FLASH, LOGIN, PASSWORD, mesaj, NUMBER
-		print "URL: ", urlSon
 		try:
 			result = urllib2.urlopen(urlSon).read()
 		except URLError, e:
 			return False, 'Error connecting to service:%s\n\n %s' %(e.reason, result)
 		except HTTPError, e:
-			return False, 'Error %s returnd from service\n\n %s' %(e.code, result)
+			return False, 'Error %s returned from service\n\n %s' %(e.code, result)
 		UpdatePbar(self, MainWindow, app, "2", "Checking reply")
 		re_suc = re.compile('OK')
 		if re_suc.search(result):
@@ -736,3 +734,167 @@ class provider_MutluSMS_tu(provider):
 		else:
 		    return False, 'Failed. Provider responded: %s' %(ERROR_MSG[result.strip("HATA:")])
 		MainWindow.Stat.close()
+
+# VoipBusterPro 1.0
+# API Docs: http://www.voipbusterpro.com/en/sms_instructions.html
+# VoipBusterPro Provider written by Bjoern Olausson <maemo@olausson.de>
+class provider_VoipBusterPro(provider):
+	def getName(self):
+		return 'VoipBusterPro'
+	def hasAdvancedFeatures(self):
+		return True
+	def AdvModName(self):
+		return 'voipbusterpro'
+	def chars_per_sms(self):
+		return 160, 160
+	def num_regexp(self, num):
+		# Remove everything except numbers and "+"
+		num = re.sub(r'[^(0-9)|\+]', '', num)
+		#Since we can send SMS anywhere it does not make sense to check for vlidity
+		return True, num, 'Valid Number'
+	def SetupGUI(self, MainWindow):
+		conn = sqlite3.connect('www2sms.db')
+		c = conn.cursor()
+		ALIAS = unicode(MainWindow.AccSet.ui.lineEdit_SetupNewAlias.text())
+		ADVANCED = ""
+		try:
+			ADVANCED = str(c.execute('select advanced FROM login WHERE alias=?', (ALIAS,)).fetchall()[0][0])
+		except sqlite3.OperationalError:
+			pass
+		if ADVANCED != "None":
+			MainWindow.AdvSet.ui.lineEdit_AdvancedText.setText(ADVANCED)
+		c.close()
+		conn.close()
+
+		def on_AdvSetSave_clicked():
+			ALIAS = unicode(MainWindow.AccSet.ui.lineEdit_SetupNewAlias.text())
+			conn = sqlite3.connect('www2sms.db')
+			c = conn.cursor()
+			DB_SENDER = str(c.execute('select advanced FROM login WHERE alias=?', (ALIAS,)).fetchall()[0][0])
+			SENDER = str(MainWindow.AdvSet.ui.lineEdit_AdvancedText.text())
+			if SENDER != "":
+			    if DB_SENDER == "None" or SENDER != DB_SENDER :
+				c.execute('UPDATE login SET advanced=? WHERE alias=?', (SENDER, ALIAS))
+				conn.commit()
+			c.close()
+			conn.close()
+			# Let the user know that we have saved the the account/changes
+			QtGui.QMessageBox.information(MainWindow.AdvSet, 'www2sms', "saved")
+
+		QtCore.QObject.connect(MainWindow.AdvSet.ui.pushButton_Save, QtCore.SIGNAL("clicked()"), on_AdvSetSave_clicked)
+
+	def get_advanced_setting(self, MainWindow):
+		# Read Sender
+		SENDER = MainWindow.AdvSet.ui.lineEdit_AdvancedText.text()
+		return SENDER
+
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
+    		#https://www.voipbusterpro.com/myaccount/sendsms.php?username=xxxxxxxxxx​&password=xxxxxxxxxx&from=xxxxxxxxxx&to=xxxxxxxxxx&text=xxxxxxxxxx
+		SENDER = self.get_advanced_setting(MainWindow)
+		if SENDER == "":
+			return False, 'A sender is required in the advanced Setup'
+		MainWindow.Stat.show()
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(2)
+		#API URL
+		url = "https://www.voipbusterpro.com/myaccount/sendsms.php"
+		#Remove invalid chars from message
+		MESSAGE = re.sub(r'\^|\{|\}|\[|\]|\~|\\|\|', '', SMSTEXT)
+		#Assemble REQUEST
+		urlSon = url + "?username=%s&password=%s&from=%s&to=%s&text=%s" %(LOGIN, PASSWORD, SENDER, NUMBER, urllib.quote_plus(MESSAGE))
+		UpdatePbar(self, MainWindow, app, "1", "Sending SMS")
+		try:
+			result = urllib2.urlopen(urlSon).read()
+		except URLError, e:
+			return False, 'Error connecting to service:%s\n\n %s' %(e.reason, result)
+		except HTTPError, e:
+			return False, 'Error %s returned from service\n\n %s' %(e.code, result)
+		UpdatePbar(self, MainWindow, app, "2", "Checking reply")
+		re_suc = re.compile('OK')
+		if re_suc.search(result):
+		    return True, '%s' %(result)
+		else:
+		    return False, 'Failed. Provider responded: %s' %(result)
+		MainWindow.Stat.close()
+
+# Telbo 1.0
+# API Docs: http://www.telbo.com/en/sms_instructions.html
+# Telbo Provider written by Bjoern Olausson <maemo@olausson.de>
+class provider_Telbo(provider):
+	def getName(self):
+		return 'Telbo'
+	def hasAdvancedFeatures(self):
+		return True
+	def AdvModName(self):
+		return 'telbo'
+	def chars_per_sms(self):
+		return 160, 160
+	def num_regexp(self, num):
+		# Remove everything except numbers and "+"
+		num = re.sub(r'[^(0-9)|\+]', '', num)
+		#Since we can send SMS anywhere it does not make sense to check for vlidity
+		return True, num, 'Valid Number'
+	def SetupGUI(self, MainWindow):
+		conn = sqlite3.connect('www2sms.db')
+		c = conn.cursor()
+		ALIAS = unicode(MainWindow.AccSet.ui.lineEdit_SetupNewAlias.text())
+		ADVANCED = ""
+		try:
+			ADVANCED = str(c.execute('select advanced FROM login WHERE alias=?', (ALIAS,)).fetchall()[0][0])
+		except sqlite3.OperationalError:
+			pass
+		if ADVANCED != "None":
+			MainWindow.AdvSet.ui.lineEdit_AdvancedText.setText(ADVANCED)
+		c.close()
+		conn.close()
+
+		def on_AdvSetSave_clicked():
+			ALIAS = unicode(MainWindow.AccSet.ui.lineEdit_SetupNewAlias.text())
+			conn = sqlite3.connect('www2sms.db')
+			c = conn.cursor()
+			DB_SENDER = str(c.execute('select advanced FROM login WHERE alias=?', (ALIAS,)).fetchall()[0][0])
+			SENDER = str(MainWindow.AdvSet.ui.lineEdit_AdvancedText.text())
+			if SENDER != "":
+			    if DB_SENDER == "None" or SENDER != DB_SENDER :
+				c.execute('UPDATE login SET advanced=? WHERE alias=?', (SENDER, ALIAS))
+				conn.commit()
+			c.close()
+			conn.close()
+			# Let the user know that we have saved the the account/changes
+			QtGui.QMessageBox.information(MainWindow.AdvSet, 'www2sms', "saved")
+
+		QtCore.QObject.connect(MainWindow.AdvSet.ui.pushButton_Save, QtCore.SIGNAL("clicked()"), on_AdvSetSave_clicked)
+
+	def get_advanced_setting(self, MainWindow):
+		# Read Sender
+		SENDER = MainWindow.AdvSet.ui.lineEdit_AdvancedText.text()
+		return SENDER
+
+	def sendSMS(self, MainWindow, app, NUMBER, SMSTEXT, LOGIN, PASSWORD):
+    		#https://www.telbo.com/myaccount/sendsms.php?username=xxxxxxxxxx​&password=xxxxxxxxxx&from=xxxxxxxxxx&to=xxxxxxxxxx&text=xxxxxxxxxx
+		SENDER = self.get_advanced_setting(MainWindow)
+		if SENDER == "":
+			return False, 'A sender is required in the advanced Setup'
+		MainWindow.Stat.show()
+		MainWindow.Stat.ui.progressBar.setMinimum(0)
+		MainWindow.Stat.ui.progressBar.setMaximum(2)
+		#API URL
+		url = "https://www.telbo.com/myaccount/sendsms.php"
+		#Remove invalid chars from message
+		MESSAGE = re.sub(r'\^|\{|\}|\[|\]|\~|\\|\|', '', SMSTEXT)
+		#Assemble REQUEST
+		urlSon = url + "?username=%s&password=%s&from=%s&to=%s&text=%s" %(LOGIN, PASSWORD, SENDER, NUMBER, urllib.quote_plus(MESSAGE))
+		UpdatePbar(self, MainWindow, app, "1", "Sending SMS")
+		try:
+			result = urllib2.urlopen(urlSon).read()
+		except URLError, e:
+			return False, 'Error connecting to service:%s\n\n %s' %(e.reason, result)
+		except HTTPError, e:
+			return False, 'Error %s returned from service\n\n %s' %(e.code, result)
+		UpdatePbar(self, MainWindow, app, "2", "Checking reply")
+		re_suc = re.compile('OK')
+		if re_suc.search(result):
+		    return True, '%s' %(result)
+		else:
+		    return False, 'Failed. Provider responded: %s' %(result)
+		MainWindow.Stat.close()
\ No newline at end of file
